@@ -234,6 +234,7 @@ class MetadataBox(QtWidgets.QTableWidget):
         self.files = set()
         self.tracks = set()
         self.objects = set()
+        self.tag_diff = None
         self.selection_mutex = QtCore.QMutex()
         self.selection_dirty = False
         self.editing = None  # the QTableWidgetItem being edited
@@ -334,7 +335,7 @@ class MetadataBox(QtWidgets.QTableWidget):
             column = item.column()
             tag = self.tag_diff.tag_names[item.row()]
             if column == self.COLUMN_NEW and self.tag_is_editable(tag):
-                self.set_tag_values(tag, self.clipboard)
+                self._set_tag_values(tag, self.clipboard)
                 self.update()
 
     def update_clipboard(self):
@@ -350,7 +351,7 @@ class MetadataBox(QtWidgets.QTableWidget):
         if old == new:
             self.editing.setText(old[0])
         else:
-            self.set_tag_values(tag, new)
+            self._set_tag_values(tag, new)
         self.editing = None
         self.update(drop_album_caches=tag == 'album')
 
@@ -387,6 +388,7 @@ class MetadataBox(QtWidgets.QTableWidget):
                     menu.addAction(remove_from_preserved_tags_action)
             removals = []
             useorigs = []
+            mergeorigs = []
             item = self.currentItem()
             if item:
                 column = item.column()
@@ -407,23 +409,21 @@ class MetadataBox(QtWidgets.QTableWidget):
                         file_tracks = []
                         track_albums = set()
                         for file in self.files:
-                            objects = [file]
+                            extra_objects = []
                             if file.parent in self.tracks and len(self.files & set(file.parent.files)) == 1:
-                                objects.append(file.parent)
+                                extra_objects.append(file.parent)
                                 file_tracks.append(file.parent)
                                 track_albums.add(file.parent.album)
-                            orig_values = list(file.orig_metadata.getall(tag)) or [""]
-                            useorigs.append(partial(self.set_tag_values, tag, orig_values, objects))
+                            useorigs.append(partial(self._use_orig_tags, file, tag, extra_objects))
+                            mergeorigs.append(partial(self._merge_orig_tags, file, tag, extra_objects))
                         for track in set(self.tracks)-set(file_tracks):
-                            objects = [track]
-                            orig_values = list(track.orig_metadata.getall(tag)) or [""]
-                            useorigs.append(partial(self.set_tag_values, tag, orig_values, objects))
+                            useorigs.append(partial(self._use_orig_tags, track, tag))
+                            mergeorigs.append(partial(self._merge_orig_tags, track, tag))
                             track_albums.add(track.album)
                         for album in track_albums:
-                            objects = [album]
-                            orig_values = list(album.orig_metadata.getall(tag)) or [""]
-                            useorigs.append(partial(self.set_tag_values, tag, orig_values, objects))
-                remove_tag_action = QtWidgets.QAction(_("Remove"), self.parent)
+                            useorigs.append(partial(self._use_orig_tags, album, tag))
+                            mergeorigs.append(partial(self._merge_orig_tags, album, tag))
+                remove_tag_action = QtWidgets.QAction(_("Remove"), self)
                 remove_tag_action.triggered.connect(partial(self._apply_update_funcs, removals))
                 remove_tag_action.setShortcut(self.remove_tag_shortcut.key())
                 remove_tag_action.setEnabled(bool(removals))
@@ -433,6 +433,9 @@ class MetadataBox(QtWidgets.QTableWidget):
                     use_orig_value_action = QtWidgets.QAction(name, self.parent)
                     use_orig_value_action.triggered.connect(partial(self._apply_update_funcs, useorigs))
                     menu.addAction(use_orig_value_action)
+                    merge_tags_action = QtWidgets.QAction(_("Merge Original Values"), self)
+                    merge_tags_action.triggered.connect(partial(self._apply_update_funcs, mergeorigs))
+                    menu.addAction(merge_tags_action)
                     menu.addSeparator()
                 if single_tag:
                     menu.addSeparator()
@@ -459,8 +462,20 @@ class MetadataBox(QtWidgets.QTableWidget):
                 f()
         self.parent.update_selection(new_selection=False, drop_album_caches=True)
 
+    def _use_orig_tags(self, obj, tag, extra_objects=None):
+        orig_values = list(obj.orig_metadata.getall(tag)) or [""]
+        self._set_tag_values_extra(tag, orig_values, obj, extra_objects)
+
+    def _merge_orig_tags(self, obj, tag, extra_objects=None):
+        values = list(obj.orig_metadata.getall(tag))
+        for new_value in obj.metadata.getall(tag):
+            if new_value not in values:
+                values.append(new_value)
+        self._set_tag_values_extra(tag, values, obj, extra_objects)
+
     def edit_tag(self, tag):
-        EditTagDialog(self.parent, tag).exec_()
+        if self.tag_diff is not None:
+            EditTagDialog(self.parent, tag).exec_()
 
     def edit_selected_tag(self):
         tags = self.selected_tags(filter_func=self.tag_is_editable)
@@ -472,7 +487,13 @@ class MetadataBox(QtWidgets.QTableWidget):
         config.persist['show_changes_first'] = checked
         self.update()
 
-    def set_tag_values(self, tag, values, objects=None):
+    def _set_tag_values_extra(self, tag, values, obj, extra_objects):
+        objects = [obj]
+        if extra_objects:
+            objects.extend(extra_objects)
+        self._set_tag_values(tag, values, objects=objects)
+
+    def _set_tag_values(self, tag, values, objects=None):
         if objects is None:
             objects = self.objects
         with self.parent.ignore_selection_changes:
@@ -488,7 +509,7 @@ class MetadataBox(QtWidgets.QTableWidget):
                     obj.update()
 
     def remove_tag(self, tag):
-        self.set_tag_values(tag, [])
+        self._set_tag_values(tag, [])
 
     def remove_selected_tags(self):
         for tag in self.selected_tags(filter_func=self.tag_is_removable):
