@@ -2,7 +2,7 @@
 #
 # Picard, the next-generation MusicBrainz tagger
 #
-# Copyright (C) 2018-2022 Philipp Wolfer
+# Copyright (C) 2018-2022, 2024 Philipp Wolfer
 # Copyright (C) 2019-2022 Laurent Monin
 # Copyright (C) 2021 Bob Swift
 # Copyright (C) 2021 Sophist-UK
@@ -225,18 +225,18 @@ class FileNamingTest(PicardTestCase):
 
     def test_make_filename_no_move_and_rename(self):
         filename = self.file.make_filename(self.file.filename, self.metadata)
-        self.assertEqual(os.path.realpath(self.file.filename), filename)
+        self.assertEqual(os.path.normpath(self.file.filename), filename)
 
     def test_make_filename_rename_only(self):
         config.setting['rename_files'] = True
         filename = self.file.make_filename(self.file.filename, self.metadata)
-        self.assertEqual(os.path.realpath('/somepath/sometitle.mp3'), filename)
+        self.assertEqual(os.path.normpath('/somepath/sometitle.mp3'), filename)
 
     def test_make_filename_move_only(self):
         config.setting['move_files'] = True
         filename = self.file.make_filename(self.file.filename, self.metadata)
         self.assertEqual(
-            os.path.realpath('/media/music/somealbum/somefile.mp3'),
+            os.path.normpath('/media/music/somealbum/somefile.mp3'),
             filename)
 
     def test_make_filename_move_and_rename(self):
@@ -244,7 +244,7 @@ class FileNamingTest(PicardTestCase):
         config.setting['move_files'] = True
         filename = self.file.make_filename(self.file.filename, self.metadata)
         self.assertEqual(
-            os.path.realpath('/media/music/somealbum/sometitle.mp3'),
+            os.path.normpath('/media/music/somealbum/sometitle.mp3'),
             filename)
 
     def test_make_filename_move_relative_path(self):
@@ -252,39 +252,39 @@ class FileNamingTest(PicardTestCase):
         config.setting['move_files_to'] = 'subdir'
         filename = self.file.make_filename(self.file.filename, self.metadata)
         self.assertEqual(
-            os.path.realpath('/somepath/subdir/somealbum/somefile.mp3'),
+            os.path.normpath('/somepath/subdir/somealbum/somefile.mp3'),
             filename)
 
     def test_make_filename_empty_script(self):
         config.setting['rename_files'] = True
         config.setting['file_renaming_scripts'] = {'test_id': {'script': '$noop()'}}
         filename = self.file.make_filename(self.file.filename, self.metadata)
-        self.assertEqual(os.path.realpath('/somepath/somefile.mp3'), filename)
+        self.assertEqual(os.path.normpath('/somepath/somefile.mp3'), filename)
 
     def test_make_filename_empty_basename(self):
         config.setting['move_files'] = True
         config.setting['rename_files'] = True
         config.setting['file_renaming_scripts'] = {'test_id': {'script': '/somedir/$noop()'}}
         filename = self.file.make_filename(self.file.filename, self.metadata)
-        self.assertEqual(os.path.realpath('/media/music/somedir/somefile.mp3'), filename)
+        self.assertEqual(os.path.normpath('/media/music/somedir/somefile.mp3'), filename)
 
     def test_make_filename_no_extension(self):
         config.setting['rename_files'] = True
         file_ = FakeMp3File('/somepath/_')
         filename = file_.make_filename(file_.filename, self.metadata)
-        self.assertEqual(os.path.realpath('/somepath/sometitle.mp3'), filename)
+        self.assertEqual(os.path.normpath('/somepath/sometitle.mp3'), filename)
 
     def test_make_filename_lowercase_extension(self):
         config.setting['rename_files'] = True
         file_ = FakeMp3File('/somepath/somefile.MP3')
         filename = file_.make_filename(file_.filename, self.metadata)
-        self.assertEqual(os.path.realpath('/somepath/sometitle.mp3'), filename)
+        self.assertEqual(os.path.normpath('/somepath/sometitle.mp3'), filename)
 
     def test_make_filename_scripted_extension(self):
         config.setting['rename_files'] = True
         config.setting['file_renaming_scripts'] = {'test_id': {'script': '$set(_extension,.foo)%title%'}}
         filename = self.file.make_filename(self.file.filename, self.metadata)
-        self.assertEqual(os.path.realpath('/somepath/sometitle.foo'), filename)
+        self.assertEqual(os.path.normpath('/somepath/sometitle.foo'), filename)
 
     def test_make_filename_replace_trailing_dots(self):
         config.setting['rename_files'] = True
@@ -296,7 +296,7 @@ class FileNamingTest(PicardTestCase):
         })
         filename = self.file.make_filename(self.file.filename, metadata)
         self.assertEqual(
-            os.path.realpath('/media/music/somealbum_/sometitle.mp3'),
+            os.path.normpath('/media/music/somealbum_/sometitle.mp3'),
             filename)
 
     @unittest.skipUnless(not IS_WIN, "non-windows test")
@@ -310,7 +310,7 @@ class FileNamingTest(PicardTestCase):
         })
         filename = self.file.make_filename(self.file.filename, metadata)
         self.assertEqual(
-            os.path.realpath('/media/music/somealbum./sometitle.mp3'),
+            os.path.normpath('/media/music/somealbum./sometitle.mp3'),
             filename)
 
     def test_make_filename_replace_leading_dots(self):
@@ -323,7 +323,7 @@ class FileNamingTest(PicardTestCase):
         })
         filename = self.file.make_filename(self.file.filename, metadata)
         self.assertEqual(
-            os.path.realpath('/media/music/_somealbum/_sometitle.mp3'),
+            os.path.normpath('/media/music/_somealbum/_sometitle.mp3'),
             filename)
 
 
