@@ -3,6 +3,7 @@
 # Picard, the next-generation MusicBrainz tagger
 #
 # Copyright (C) 2022 Laurent Monin
+# Copyright (C) 2024 Philipp Wolfer
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -21,7 +22,11 @@
 
 from test.picardtestcase import PicardTestCase
 
-from picard.oauth import OAuthManager
+from picard.oauth import (
+    OAuthManager,
+    base64url_encode,
+    s256_encode,
+)
 
 
 class OAuthManagerTest(PicardTestCase):
@@ -35,3 +40,15 @@ class OAuthManagerTest(PicardTestCase):
         }
         data = OAuthManager._query_data(params)
         self.assertEqual(data, "a%26b=a+b&c+d=c%26d&e%3Df=e%3Df")
+
+    def test_s256_encode(self):
+        code_verifier = b'dBjftJeZ4CVP-mB92K27uhbUJU1p1r_wW1gFWFOEjXk'
+        code_challenge = s256_encode(code_verifier)
+        self.assertEqual(b'E9Melhoa2OwvFrEMTJguCHaoeK1t8URWbuGJSstw-cM', code_challenge)
+
+    def test_base64url_encode(self):
+        b = bytes([116, 24, 223, 180, 151, 153, 224, 37, 79, 250, 96, 125, 216, 173,
+            187, 186, 22, 212, 37, 77, 105, 214, 191, 240, 91, 88, 5, 88, 83,
+            132, 141, 121])
+        encoded = base64url_encode(b)
+        self.assertEqual(b'dBjftJeZ4CVP-mB92K27uhbUJU1p1r_wW1gFWFOEjXk', encoded)
